AnasLocalizationScope class abstract
Public API contract exposed by AnasLocalization.of.
This keeps the internal inherited widget private while exposing a stable, public type to package consumers.
Constructors
Properties
- app → Widget
-
no setter
- dictionary → Dictionary
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInitialized → bool
-
no setter
- locale → Locale
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedLocales
→ List<
Locale> -
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setLocale(
Locale locale) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited