AnasLocalizationWithSetup class
A complete localization provider with language setup overlay
This widget shows a loading screen during language changes, similar to iPhone's setup screen
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- AnasLocalizationWithSetup
Constructors
-
AnasLocalizationWithSetup({Key? key, required Widget child, required Locale fallbackLocale, required String assetPath, required List<
Locale> assetLocales, Dictionary dictionaryFactory(Map<String, dynamic> , {required String locale})?, Duration? setupDuration, bool enableSetupScreen = true, Color? overlayBackgroundColor, Color? overlayTextColor, bool showProgressIndicator = true}) -
const
Properties
-
assetLocales
→ List<
Locale> -
List of supported locales
final
- assetPath → String
-
Path to translation assets
final
- child → Widget
-
The child widget (typically MaterialApp)
final
-
dictionaryFactory
→ Dictionary Function(Map<
String, dynamic> , {required String locale})? -
Optional dictionary factory for custom Dictionary classes
final
- enableSetupScreen → bool
-
Whether to show the setup screen (disable for testing)
final
- fallbackLocale → Locale
-
Fallback locale if device locale is not supported
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- overlayBackgroundColor → Color?
-
Background color of the setup overlay
final
- overlayTextColor → Color?
-
Text color of the setup overlay
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setupDuration → Duration?
-
Duration to show the setup screen
Defaults to 1500ms for a realistic setup feel
final
- showProgressIndicator → bool
-
Whether to show progress indicator
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited