ApiResponse<T> class

REST API response wrapper for consistent responses

Constructors

ApiResponse({required bool success, required int statusCode, T? data, String? error, DateTime? timestamp})
const

Properties

data → T?
final
error → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
final
success → bool
final
timestamp → DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited