CatalogMeta class

Constructors

CatalogMeta({required List<String> locales, required Map<String, String> localeDirections, required String sourceLocale, required String fallbackLocale, required String langDirectory, required String format, required String stateFilePath, required int uiPort, required int apiPort, required bool autoGenerateDictionary})
const

Properties

apiPort int
final
autoGenerateDictionary bool
final
fallbackLocale String
final
format String
final
hashCode int
The hash code for this object.
no setterinherited
langDirectory String
final
localeDirections Map<String, String>
final
locales List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceLocale String
final
stateFilePath String
final
uiPort int
final

Methods

copyWith({List<String>? locales, Map<String, String>? localeDirections, String? sourceLocale, String? fallbackLocale, String? langDirectory, String? format, String? stateFilePath, int? uiPort, int? apiPort, bool? autoGenerateDictionary}) CatalogMeta
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) CatalogMeta