CatalogStateDto class

Catalog state DTO for API serialization

Constructors

CatalogStateDto({required String sourceLocale, required String format, required Map<String, String> languageGroupFallbacks, required Map<String, String> customLocaleDirections, required int totalLocales, required int totalKeys})
const
CatalogStateDto.fromJson(Map<String, dynamic> json)
factory

Properties

customLocaleDirections Map<String, String>
final
format String
final
hashCode int
The hash code for this object.
no setterinherited
languageGroupFallbacks Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceLocale String
final
totalKeys int
final
totalLocales int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited