RemoteLocalizationUnsupported class
- Inheritance
-
- Object
- RemoteLocalizationUpdateResult
- RemoteLocalizationUnsupported
Constructors
- RemoteLocalizationUnsupported({required RemoteLocalizationScope scope, required DateTime startedAt, required DateTime completedAt})
-
const
Properties
- completedAt → DateTime
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → RemoteLocalizationScope
-
finalinherited
- startedAt → DateTime
-
finalinherited
- status → RemoteLocalizationUpdateStatus
-
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited