CatalogApiClient class

Constructors

CatalogApiClient({required Uri baseUri, HttpClientAdapter? httpClient})

Properties

baseUri → Uri
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addKey({required String keyPath, required Map<String, dynamic> valuesByLocale, String? note, bool markGreenIfComplete = true}) → Future<CatalogRow>
addLocale({required String locale, String? direction}) → Future<void>
Creates a new empty locale file.
bulkReview({required List<CatalogReviewTarget> targets}) → Future<CatalogBulkReviewResult>
close() → void
deleteCell({required String keyPath, required String locale}) → Future<CatalogRow>
deleteKey({required String keyPath}) → Future<void>
deleteLocale({required String locale}) → Future<void>
Deletes a locale file permanently.
loadActivity({required String keyPath}) → Future<List<CatalogActivityEvent>>
loadMeta() → Future<CatalogMeta>
loadRows({String search = '', String status = ''}) → Future<List<CatalogRow>>
loadSummary() → Future<CatalogSummary>
markReviewed({required String keyPath, required String locale}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateAutoGenerateDictionary({required bool autoGenerateDictionary}) → Future<void>
updateCell({required String keyPath, required String locale, required dynamic value}) → Future<CatalogRow>
updateFallbackLocale({required String fallbackLocale}) → Future<void>
Updates the fallback locale in config.
updateKeyDataType({required String keyPath, required String dataType}) → Future<CatalogRow>
updateKeyNote({required String keyPath, String? note}) → Future<CatalogRow>

Operators

operator ==(Object other) → bool
The equality operator.
inherited