CatalogConfig class

Constructors

CatalogConfig({required int version, required String langDir, required CatalogFileFormat format, required String fallbackLocale, required String? sourceLocale, required String stateFile, required int uiPort, required int apiPort, required bool openBrowser, required String arbFilePrefix, required bool hideCatalogUiKeys, required bool autoGenerateDictionary})
const

Properties

apiPort int
final
arbFilePrefix String
final
autoGenerateDictionary bool
final
effectiveSourceLocale String
no setter
fallbackLocale String
final
format CatalogFileFormat
final
hashCode int
The hash code for this object.
no setterinherited
hideCatalogUiKeys bool
final
langDir String
final
openBrowser bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceLocale String?
final
stateFile String
final
uiPort int
final
version int
final

Methods

copyWith({int? version, String? langDir, CatalogFileFormat? format, String? fallbackLocale, String? sourceLocale, bool clearSourceLocale = false, String? stateFile, int? uiPort, int? apiPort, bool? openBrowser, String? arbFilePrefix, bool? hideCatalogUiKeys, bool? autoGenerateDictionary}) CatalogConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveLangDirectory(String projectRootPath) String
resolveStateFilePath(String projectRootPath) String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
toYamlString() String

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

defaults() CatalogConfig
load({String path = defaultConfigPath}) Future<CatalogConfig>
writeConfig({required String path, required CatalogConfig config}) Future<void>
Writes config to file, creating it if it doesn't exist or updating existing.
writeDefault({String path = defaultConfigPath}) Future<void>

Constants

defaultConfigPath → const String