CatalogDataset class

Constructors

CatalogDataset({required Map<String, Map<String, dynamic>> translationsByLocale, Map<String, Map<String, dynamic>> arbMetadataByLocale = const <String, Map<String, dynamic>>{}})

Properties

arbMetadataByLocale → Map<String, Map<String, dynamic>>
final
hashCode → int
The hash code for this object.
no setterinherited
locales → List<String>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
translationsByLocale → Map<String, Map<String, dynamic>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited