CatalogQueueController class

Inheritance

Constructors

CatalogQueueController({required CatalogApiClient client, required CatalogWorkspacePreferencesController preferences})

Properties

error → String?
no setter
hasAnyKeys → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
hasQuery → bool
no setter
initialized → bool
no setter
loading → bool
no setter
meta → CatalogMeta?
no setter
rows → List<CatalogRow>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
no setter
sortMode → CatalogQueueSortMode
no setter
statusFilter → CatalogRowStatusFilter
no setter
summary → CatalogSummary?
no setter
visibleSections → List<CatalogQueueSection>
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addLocaleOptimistic(String locale, String direction) → void
addRowOptimistic(CatalogRow row) → void
bulkReviewOptimistic(List<CatalogReviewTarget> targets) → void
dispose() → void
Discards any resources used by the object.
override
initialize() → Future<void>
isSectionCollapsed(CatalogQueueSection section) → bool
namespaceForKey(String keyPath) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
refresh({bool reloadMeta = false}) → Future<void>
refreshSummary() → Future<void>
removeKey(String keyPath) → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeLocaleOptimistic(String locale) → void
removeRowOptimistic(String keyPath) → void
rowByKey(String keyPath) → CatalogRow?
rowsForSection(CatalogQueueSection section) → List<CatalogRow>
sectionCount(CatalogQueueSection section) → int
setSectionCollapsed(CatalogQueueSection section, bool collapsed) → Future<void>
toString() → String
A string representation of this object.
inherited
updateRowStatusOptimistic(String keyPath, CatalogCellStatus newStatus) → void
updateRowValueOptimistic(String keyPath, String locale, dynamic value) → void
updateSearch(String value) → void
updateSortMode(CatalogQueueSortMode mode) → Future<void>
updateStatusFilter(CatalogRowStatusFilter filter) → Future<void>
upsertRow(CatalogRow row) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited