CatalogRuntime class

Constructors

CatalogRuntime({required CatalogService service, required CatalogConfig config, String host = '127.0.0.1'})

Properties

apiUrl → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
host → String
final
isRunning → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uiUrl → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → Future<void>
stop() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited