CatalogSelectionController class

Inheritance

Properties

compactDetailOpen bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedKey String?
no setter
selectedLocale String?
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clearCompactDetail() → void
defaultEditorLocale(CatalogMeta? meta, {String? fallbackLocale}) String
dispose() → void
Discards any resources used by the object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
openRow(String keyPath) → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
revealSelection() → void
selectedRow(List<CatalogRow> rows) CatalogRow?
selectLocale(String locale) Future<void>
sync({required List<CatalogRow> rows, required CatalogMeta? meta}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited