CatalogStatusEngine class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
hashSourceValue(dynamic value)
→ String
-
-
isLegacyHash(String hash)
→ bool
-
Returns true if
hash is in the legacy SHA-1 format (40 hex characters).
-
markGreen({required CatalogCellState? current, required String sourceHash, required DateTime now})
→ CatalogCellState
-
-
markRed({required CatalogCellState? current, required String reason, required DateTime now})
→ CatalogCellState
-
-
markWarning({required CatalogCellState? current, required String reason, required DateTime now})
→ CatalogCellState
-
-
newKeyState({required List<String> locales, required String sourceLocale, required String sourceHash, required Map<String, dynamic> valuesByLocale, required bool markGreenIfComplete, required DateTime now})
→ CatalogKeyState
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited