CatalogUiServer class

Constructors

CatalogUiServer({String host = '127.0.0.1', required int port, required String apiUrl})

Properties

apiUrl → String
final
hashCode → int
The hash code for this object.
no setterinherited
host → String
final
isRunning → bool
no setter
port → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → Future<void>
stop() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited