CatalogWorkspaceController class

Inheritance

Constructors

CatalogWorkspaceController({required CatalogApiClient client, String? fallbackLocale})
CatalogWorkspaceController.forPreview({required CatalogApiClient client, Locale? fallbackLocale})

Properties

activity CatalogActivityController
latefinal
activityError String?
no setter
activityEvents List<CatalogActivityEvent>
no setter
activityLoading bool
no setter
compactDetailOpen bool
no setter
defaultEditorLocale String
no setter
drafts CatalogDraftController
latefinal
error String?
no setter
fallbackLocale String?
final
hasAnyKeys bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
initialized bool
no setter
loading bool
no setter
meta CatalogMeta?
no setter
queue CatalogQueueController
latefinal
rows List<CatalogRow>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
no setter
selectedKey String?
no setter
selectedLocale String?
no setter
selectedRow CatalogRow?
no setter
selection CatalogSelectionController
latefinal
sortMode → CatalogQueueSortMode
no setter
statusFilter → CatalogRowStatusFilter
no setter
summary CatalogSummary?
no setter
visibleSections List<CatalogQueueSection>
no setter
workspacePreferences CatalogWorkspacePreferencesController
latefinal

Methods

addCustomLocale(String localeCode, String direction) Future<void>
Adds a custom locale with manual direction specification.
addGenderBranch({required CatalogRow row, required String locale, required String? category, required String gender}) → void
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addLocale(String locale, String direction, BuildContext? context) Future<void>
Adds a new empty locale file.
addPluralBranch({required CatalogRow row, required String locale, required String category}) → void
bulkReviewTargets(List<CatalogReviewTarget> targets) Future<void>
clearSelection() Future<void>
createKey({required String keyPath, required Map<String, dynamic> valuesByLocale, String? note}) Future<void>
deleteKey(CatalogRow row) Future<void>
deleteLocale(String locale, BuildContext? context) Future<void>
Deletes a locale file permanently.
deleteValue({required CatalogRow row, required String locale}) Future<void>
dispose() → void
Discards any resources used by the object.
override
flushActiveDrafts() Future<void>
flushActiveNoteDraft() Future<void>
flushActiveValueDraft() Future<void>
flushNoteDraft(CatalogRow row) Future<void>
flushValueDraft(CatalogRow row, String locale) Future<void>
formatTimestamp(DateTime? value, Locale locale) String
initialize() Future<void>
isSectionCollapsed(CatalogQueueSection section) bool
listOptionalTypeWarnings(CatalogRow row, String locale) List<String>
Optional type warnings for typed keys (e.g. _type "plural" with missing forms). Shown in Catalog UI; do not block Done.
localeDirection(String locale) String
markReviewed({required CatalogRow row, required String locale}) Future<void>
namespaceForKey(String keyPath) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
noteDraftFor(CatalogRow row) CatalogNoteDraft
notifyListeners() → void
Call all the registered listeners.
inherited
refresh() Future<void>
removeBranch({required CatalogRow row, required String locale, required List<String> path}) → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
rowByKey(String keyPath) CatalogRow?
rowsForSection(CatalogQueueSection section) List<CatalogRow>
rowSyncState(String keyPath) → CatalogDraftSyncState
sectionCount(CatalogQueueSection section) int
selectLocale(String locale) Future<void>
selectRow(String keyPath) Future<void>
setAutoGenerateDictionary(bool value) Future<void>
setFallbackLocale(String locale, BuildContext? context) Future<void>
Updates the fallback locale in config.
setSectionCollapsed(CatalogQueueSection section, bool collapsed) Future<void>
toString() String
A string representation of this object.
inherited
updateAdvancedJsonDraft({required CatalogRow row, required String locale, required String text}) → void
updateBranchDraft({required CatalogRow row, required String locale, required List<String> path, required String text}) → void
updateKeyDataType(CatalogRow row, DataType dataType) Future<void>
updateNoteDraft(CatalogRow row, String value) → void
updatePlainDraft({required CatalogRow row, required String locale, required String text}) → void
updateSearch(String value) → void
updateSortMode(CatalogQueueSortMode mode) Future<void>
updateStatusFilter(CatalogRowStatusFilter filter) Future<void>
validateDoneBlockers(CatalogRow row, String locale, CatalogLocalizations l10n) List<String>
valueDraftFor(CatalogRow row, String locale) CatalogValueDraft

Operators

operator ==(Object other) bool
The equality operator.
inherited