CatalogSummary class
Constructors
Properties
- greenCount → int
-
final
- greenRows → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- redCount → int
-
final
- redRows → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalKeys → int
-
final
- warningCount → int
-
final
- warningRows → int
-
final
Methods
-
copyWith(
{int? totalKeys, int? greenCount, int? warningCount, int? redCount, int? greenRows, int? warningRows, int? redRows}) → CatalogSummary -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → CatalogSummary