CircularFallbackException class

Exception thrown when configuring a language group fallback would create a cycle.

Inheritance

Constructors

CircularFallbackException(String locale, String attemptedFallback)

Properties

attemptedFallback String
The attempted fallback that would create a cycle.
final
hashCode int
The hash code for this object.
no setterinherited
locale String
The locale being configured.
final
message String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited