HttpTranslationLoader class

Loads translations from a remote HTTP endpoint.

Unlike asset loaders, parse and transport failures throw RemoteTranslationLoadException so callers can surface remote errors.

Inheritance

Constructors

HttpTranslationLoader({required String baseUrl, HttpClientAdapter? client, Map<String, String>? requestHeaders, List<String>? fileExtensions})

Properties

baseUrl String
final
client → HttpClientAdapter?
final
fileExtensions List<String>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
id String
no setteroverride
requestHeaders Map<String, String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

load(String basePath) Future<TranslationMap?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited