Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsGlobalCheck → bool
-
no setter
- supportsLocaleCheck → bool
-
no setter
Methods
-
checkForLocaleUpdate(
Locale locale, RemoteLocalizationVersion? cachedVersion) → Future< RemoteCheckResponse> -
checkForUpdates(
RemoteVersionSnapshot cachedVersions) → Future< RemoteCheckResponse> -
downloadPayload(
RemoteUpdateDescriptor update) → Future< RemoteLocalizationPayload> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited