ValidationOptions class

Constructors

ValidationOptions({required ValidationProfile profile, required ValidationRuleToggles ruleToggles, required bool treatExtraKeysAsWarnings, required bool failOnWarnings})
const
ValidationOptions.compatibility({required bool treatExtraKeysAsWarnings})
factory
ValidationOptions.forProfile(ValidationProfile profile, {ValidationRuleToggles? overrideRules, bool? treatExtraKeysAsWarnings, bool? failOnWarnings})
factory

Properties

failOnWarnings bool
final
hashCode int
The hash code for this object.
no setterinherited
profile ValidationProfile
final
ruleToggles ValidationRuleToggles
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
treatExtraKeysAsWarnings bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited