CatalogDraftController class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hasListeners
→ bool
-
Whether any listeners are currently registered.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addGenderBranch({required CatalogRow row, required String locale, required String? category, required String gender})
→ void
-
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
addPluralBranch({required CatalogRow row, required String locale, required String category})
→ void
-
-
bulkReviewTargets(List<CatalogReviewTarget> targets)
→ Future<void>
-
-
createKey({required String keyPath, required Map<String, dynamic> valuesByLocale, String? note})
→ Future<CatalogRow>
-
-
deleteKey(CatalogRow row)
→ Future<void>
-
-
deleteValue({required CatalogRow row, required String locale})
→ Future<void>
-
-
dispose()
→ void
-
Discards any resources used by the object.
override
-
flushNoteDraft(CatalogRow row)
→ Future<void>
-
-
flushValueDraft(CatalogRow row, String locale)
→ Future<void>
-
-
listOptionalTypeWarnings(CatalogRow row, String locale)
→ List<String>
-
Optional type warnings (e.g. key has _type "plural" but missing required forms). Shown in Catalog UI; do not block Done.
-
markReviewed({required CatalogRow row, required String locale})
→ Future<void>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
noteDraftFor(CatalogRow row)
→ CatalogNoteDraft
-
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
removeBranch({required CatalogRow row, required String locale, required List<String> path})
→ void
-
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
rowByKey(String keyPath)
→ CatalogRow?
-
-
rowSyncState(String keyPath)
→ CatalogDraftSyncState
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateAdvancedJsonDraft({required CatalogRow row, required String locale, required String text})
→ void
-
-
updateBranchDraft({required CatalogRow row, required String locale, required List<String> path, required String text})
→ void
-
-
updateKeyDataType(CatalogRow row, DataType dataType)
→ Future<void>
-
-
updateNoteDraft(CatalogRow row, String value)
→ void
-
-
updatePlainDraft({required CatalogRow row, required String locale, required String text})
→ void
-
-
validateDoneBlockers(CatalogRow row, String locale, CatalogLocalizations l10n)
→ List<String>
-
-
valueDraftFor(CatalogRow row, String locale)
→ CatalogValueDraft
-