CatalogRepository class
Constructors
- CatalogRepository({required CatalogConfig config, required String projectRootPath})
Properties
- config → CatalogConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectRootPath → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createLocaleFile(
String locale) → Future< void> - Creates a new empty locale file.
-
deleteLocaleFile(
String locale) → Future< void> - Deletes a locale file permanently.
-
listLocaleFiles(
) → Future< List< String> > - Lists all locale files in the lang directory.
-
load(
) → Future< CatalogDataset> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
CatalogDataset dataset) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited