CatalogValueDraft class

Inheritance

Constructors

CatalogValueDraft({required String keyPath, required String locale, required dynamic baseValue, required dynamic value, required CatalogEditorMode editorMode, required bool rawPinned, required String rawText})

Properties

baseValue ↔ dynamic
getter/setter pair
editorMode ↔ CatalogEditorMode
getter/setter pair
errorMessage String?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
keyPath String
final
locale String
final
rawError String?
getter/setter pair
rawPinned bool
getter/setter pair
rawText String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savedResetTimer Timer?
getter/setter pairinherited
syncState ↔ CatalogDraftSyncState
getter/setter pairinherited
timer Timer?
getter/setter pairinherited
touched bool
getter/setter pairinherited
value ↔ dynamic
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited