CatalogWorkspaceController class
Methods
-
addCustomLocale(String localeCode, String direction)
→ Future<void>
-
Adds a custom locale with manual direction specification.
-
addGenderBranch({required CatalogRow row, required String locale, required String? category, required String gender})
→ void
-
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
addLocale(String locale, String direction, BuildContext? context)
→ Future<void>
-
Adds a new empty locale file.
-
addPluralBranch({required CatalogRow row, required String locale, required String category})
→ void
-
-
bulkReviewTargets(List<CatalogReviewTarget> targets)
→ Future<void>
-
-
clearSelection()
→ Future<void>
-
-
createKey({required String keyPath, required Map<String, dynamic> valuesByLocale, String? note})
→ Future<void>
-
-
deleteKey(CatalogRow row)
→ Future<void>
-
-
deleteLocale(String locale, BuildContext? context)
→ Future<void>
-
Deletes a locale file permanently.
-
deleteValue({required CatalogRow row, required String locale})
→ Future<void>
-
-
dispose()
→ void
-
Discards any resources used by the object.
override
-
flushActiveDrafts()
→ Future<void>
-
-
flushActiveNoteDraft()
→ Future<void>
-
-
flushActiveValueDraft()
→ Future<void>
-
-
flushNoteDraft(CatalogRow row)
→ Future<void>
-
-
flushValueDraft(CatalogRow row, String locale)
→ Future<void>
-
-
formatTimestamp(DateTime? value, Locale locale)
→ String
-
-
initialize()
→ Future<void>
-
-
isSectionCollapsed(CatalogQueueSection section)
→ bool
-
-
listOptionalTypeWarnings(CatalogRow row, String locale)
→ List<String>
-
Optional type warnings for typed keys (e.g. _type "plural" with missing forms). Shown in Catalog UI; do not block Done.
-
localeDirection(String locale)
→ String
-
-
markReviewed({required CatalogRow row, required String locale})
→ Future<void>
-
-
namespaceForKey(String keyPath)
→ String
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
noteDraftFor(CatalogRow row)
→ CatalogNoteDraft
-
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
refresh()
→ Future<void>
-
-
removeBranch({required CatalogRow row, required String locale, required List<String> path})
→ void
-
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
rowByKey(String keyPath)
→ CatalogRow?
-
-
rowsForSection(CatalogQueueSection section)
→ List<CatalogRow>
-
-
rowSyncState(String keyPath)
→ CatalogDraftSyncState
-
-
sectionCount(CatalogQueueSection section)
→ int
-
-
selectLocale(String locale)
→ Future<void>
-
-
selectRow(String keyPath)
→ Future<void>
-
-
setAutoGenerateDictionary(bool value)
→ Future<void>
-
-
setFallbackLocale(String locale, BuildContext? context)
→ Future<void>
-
Updates the fallback locale in config.
-
setSectionCollapsed(CatalogQueueSection section, bool collapsed)
→ Future<void>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateAdvancedJsonDraft({required CatalogRow row, required String locale, required String text})
→ void
-
-
updateBranchDraft({required CatalogRow row, required String locale, required List<String> path, required String text})
→ void
-
-
updateKeyDataType(CatalogRow row, DataType dataType)
→ Future<void>
-
-
updateNoteDraft(CatalogRow row, String value)
→ void
-
-
updatePlainDraft({required CatalogRow row, required String locale, required String text})
→ void
-
-
updateSearch(String value)
→ void
-
-
updateSortMode(CatalogQueueSortMode mode)
→ Future<void>
-
-
updateStatusFilter(CatalogRowStatusFilter filter)
→ Future<void>
-
-
validateDoneBlockers(CatalogRow row, String locale, CatalogLocalizations l10n)
→ List<String>
-
-
valueDraftFor(CatalogRow row, String locale)
→ CatalogValueDraft
-